@@ -1,3 +1,14 @@
+// # Package: RDCOMClient
+// # Version: 0.93-0.2
+// # Title: R-DCOM Client
+// # Author: Duncan Temple Lang <duncan@wald.ucdavis.edu>
+// #     Maintainer: Duncan Temple Lang <duncan@wald.ucdavis.edu>
+// #     Description: Provides dynamic client-side access to (D)COM applications from within R.
+// # License: GPL-2
+// # Collate: classes.R COMLists.S COMError.R com.R debug.S zzz.R runTime.S
+// # URL: http://www.omegahat.org/RDCOMClient, http://www.omegahat.org
+// # http://www.omegahat.org/bugs
+
 #include "RCOMObject.h"
 #include <oleauto.h>
 #include <oaidl.h>
@@ -480,12 +491,18 @@ R_convertDCOMObjectToR(VARIANT *var)
        ans = R_createRCOMUnknownObject((void**) ptr, "COMUnknown");
       }
        break;
+  case VT_ERROR:   // to get errors such as #NUM as NaN in R  
+      ans = R_scalarReal(R_NaN);
+      break;
+      
   case VT_EMPTY:
   case VT_NULL:
+   
   case VT_VOID:
     return(R_NilValue);
     break;
-
+ 
+	
 
 /*XXX Need to fill these in */
   case VT_RECORD:
@@ -497,7 +514,7 @@ R_convertDCOMObjectToR(VARIANT *var)
     /*  case LPSTR: */
   case VT_LPWSTR:
   case VT_PTR:
-  case VT_ERROR:
+
   case VT_VARIANT:
   case VT_CARRAY:
   case VT_USERDEFINED:
